{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#gatk-HaplotypeCaller.cwl",
            "label": "gatk-HaplotypeCaller-v4.0.11.0",
            "requirements": [
                {
                    "dockerPull": "broadinstitute/gatk:4.0.11.0",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "gatk",
                "--java-options",
                "-Xmx4G",
                "HaplotypeCaller"
            ],
            "inputs": [
                {
                    "type": "string",
                    "doc": "Mode for emitting reference confidence scores [GVCF(=default) or BP_RESOLUTION]",
                    "default": "GVCF",
                    "inputBinding": {
                        "prefix": "--emit-ref-confidence"
                    },
                    "id": "#gatk-HaplotypeCaller.cwl/gatk-HaplotypeCaller-v4.0.11.0/emit-ref-conf"
                },
                {
                    "type": "File",
                    "doc": "Input BAM file",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#gatk-HaplotypeCaller.cwl/gatk-HaplotypeCaller-v4.0.11.0/input"
                },
                {
                    "type": "string",
                    "doc": "Output gVCF file name",
                    "default": "variants.g.vcf.gz",
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "id": "#gatk-HaplotypeCaller.cwl/gatk-HaplotypeCaller-v4.0.11.0/output"
                },
                {
                    "type": "File",
                    "doc": "Reference FASTA file",
                    "inputBinding": {
                        "prefix": "--reference"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk-HaplotypeCaller.cwl/gatk-HaplotypeCaller-v4.0.11.0/reference"
                }
            ],
            "arguments": [
                {
                    "id": "#gatk-HaplotypeCaller.cwl/gatk-HaplotypeCaller-v4.0.11.0/max-alt-alleles",
                    "prefix": "-max-alternate-alleles",
                    "valueFrom": "2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk-HaplotypeCaller.cwl/gatk-HaplotypeCaller-v4.0.11.0/vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools-index.cwl",
            "label": "samtools-index-v1.9",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h10a08f8_12",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.bam)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input BAM file",
                    "id": "#samtools-index.cwl/samtools-index-v1.9/bam"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-index.cwl/samtools-index-v1.9/threads"
                }
            ],
            "arguments": [
                "$(inputs.bam)"
            ],
            "outputs": [
                {
                    "id": "#samtools-index.cwl/samtools-index-v1.9/bai",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename).bai"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools-sam2bam.cwl",
            "label": "samtools-sam2bam-v1.9",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h10a08f8_12",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input SAM file",
                    "id": "#samtools-sam2bam.cwl/samtools-sam2bam-v1.9/sam"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-sam2bam.cwl/samtools-sam2bam-v1.9/threads"
                }
            ],
            "arguments": [
                "$(inputs.sam)"
            ],
            "stdout": "$(inputs.sam.nameroot).bam",
            "outputs": [
                {
                    "id": "#samtools-sam2bam.cwl/samtools-sam2bam-v1.9/bam",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sam.nameroot).bam"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools-sort.cwl",
            "label": "samtools-sort-v1.9",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h10a08f8_12",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input BAM file",
                    "id": "#samtools-sort.cwl/samtools-sort-v1.9/bam"
                },
                {
                    "type": "string",
                    "default": "2G",
                    "doc": "Maximum memory per thread; suffix K/M/G recognized",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#samtools-sort.cwl/samtools-sort-v1.9/memory"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-sort.cwl/samtools-sort-v1.9/threads"
                }
            ],
            "arguments": [
                "$(inputs.bam)"
            ],
            "stdout": "$(inputs.bam.nameroot).sort.bam",
            "outputs": [
                {
                    "id": "#samtools-sort.cwl/samtools-sort-v1.9/sorted_bam",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).sort.bam"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#util-bindBamIndex.cwl",
            "label": "Bind BAM and index file",
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$(inputs.bam)"
                        },
                        {
                            "entry": "$(inputs.bai)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": "true",
            "inputs": [
                {
                    "type": "File",
                    "id": "#util-bindBamIndex.cwl/Bind BAM and index file/bai"
                },
                {
                    "type": "File",
                    "id": "#util-bindBamIndex.cwl/Bind BAM and index file/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#util-bindBamIndex.cwl/Bind BAM and index file/bam_with_index"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "doc": "Any string that can distinguish sample.",
                    "id": "#main/outprefix"
                },
                {
                    "type": "File",
                    "doc": "FASTA file for reference genome",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/sam"
                },
                {
                    "type": "int",
                    "default": 1,
                    "id": "#main/threads"
                }
            ],
            "steps": [
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/sort_bam/sorted_bam",
                            "id": "#main/bam_indexing/bam"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/bam_indexing/threads"
                        }
                    ],
                    "out": [
                        "#main/bam_indexing/bai"
                    ],
                    "id": "#main/bam_indexing"
                },
                {
                    "run": "#util-bindBamIndex.cwl",
                    "in": [
                        {
                            "source": "#main/bam_indexing/bai",
                            "id": "#main/bind_bam_index/bai"
                        },
                        {
                            "source": "#main/sort_bam/sorted_bam",
                            "id": "#main/bind_bam_index/bam"
                        }
                    ],
                    "out": [
                        "#main/bind_bam_index/bam_with_index"
                    ],
                    "id": "#main/bind_bam_index"
                },
                {
                    "run": "#gatk-HaplotypeCaller.cwl",
                    "in": [
                        {
                            "source": "#main/bind_bam_index/bam_with_index",
                            "id": "#main/haplotype_caller/input"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/vcf"
                    ],
                    "id": "#main/haplotype_caller"
                },
                {
                    "run": "#samtools-sam2bam.cwl",
                    "in": [
                        {
                            "source": "#main/sam",
                            "id": "#main/sam2bam/sam"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/sam2bam/threads"
                        }
                    ],
                    "out": [
                        "#main/sam2bam/bam"
                    ],
                    "id": "#main/sam2bam"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/sam2bam/bam",
                            "id": "#main/sort_bam/bam"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/sort_bam/threads"
                        }
                    ],
                    "out": [
                        "#main/sort_bam/sorted_bam"
                    ],
                    "id": "#main/sort_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bind_bam_index/bam_with_index",
                    "id": "#main/sorted_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/haplotype_caller/vcf",
                    "id": "#main/vcf"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
